==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/plugins/e2p_for_each.c <==
/*
 *
 * Copyright (C) 2003-2005 tooar <tooar@gmx.net>
 * Portions copyright (C) 1999 Michael Clark
 *
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include <string.h>
#include "e2_plugins.h"
#include "e2_dialog.h"
#include "e2_filelist.h"

static void for_each_dialog (void)
{
  gchar *s, *utf;
  F_DECLARE;
  GString *command;
  GList *base, *tmp;
  FileInfo *info;

  DialogButtons result = e2_dialog_line_input (_("repeat action"), 
		_("Enter an action to execute on each\n"
		"selected file:"),
		"", 0, FALSE, &s); 

  if (result == OK)
  {
   	e2_filelist_disable_refresh ();
  	base = tmp = e2_fileview_get_selected_local (curr_view);
    if (base == NULL)
	{
	   	e2_filelist_enable_refresh ();
		return;
	}
	//FIXME support macros other than with english letters
    if (strstr (s, "%f") == NULL)
    {
      command = g_string_sized_new(128);
      for (; tmp != NULL; tmp = tmp->next)
      {
        info = tmp->data;
		utf = F_FILENAME_FROM_LOCALE (info->filename);
        g_string_printf (command, "%s \"%s\"", s, utf);
		e2_command_run (command->str, E2_COMMAND_RANGE_DEFAULT);
		F_FREE (utf);
      }
      g_string_free (command, TRUE);
    }
    else	//the command included "%f" already
    {
      for (; tmp != NULL; tmp = tmp->next)
      {
        info = tmp->data;
		utf = F_FILENAME_FROM_LOCALE (info->filename);
        if ((command = e2_utils_expand_macros (s, utf)) != NULL)
        {
          e2_command_run (command->str, E2_COMMAND_RANGE_DEFAULT);
          g_string_free (command, TRUE);
        }
		F_FREE (utf);
      }
    }
	g_free(s);
    g_list_free(base);
   	e2_filelist_enable_refresh ();
  }
}

//aname must be confined to this module
static gchar *aname;
/**
 * @brief plugin initialization function, called by main program
 *
 * @param p ptr to plugin data struct
 *
 * @return TRUE if the initialization succeeds, else FALSE
 **/
gboolean init_plugin (Plugin *p)
{
#define ANAME "foreach"
  aname = _("foreach");

  p->signature = ANAME VERSION;
  p->menu_name = _("For _each..");
  p->description = _("Execute an entered command on each selected item separately");
  p->icon = ICON_DIR"plugin_"ANAME"_"E2IP".png";  //use icon file pathname if appropriate

  if (p->plugin_cb == NULL)
  {
	  p->plugin_cb = for_each_dialog;  //set plugins menu item function
//	  E2_Action* (*action_register) () = (*p->api_lookup) (E2API_ACTION_REGISTER);
	  //no need to free this
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
	  //NULL = no data, FALSE = no argument for the function
//	  (*action_register)
	  e2_action_register_simple (action_name, E2_ACTION_TYPE_ITEM, for_each_dialog, NULL, FALSE);
	  return TRUE;
  }
  return FALSE;
}
/**
 * @brief unload this plugin
 *
 * @param p pointer to data struct for the plugin
 *
 * @return
 **/
void unload_plugin (Plugin *p)
{
//  if (p->api_lookup != NULL)
//  {
//	  gboolean (*action_unregister) () = (*p->api_lookup) (E2API_ACTION_UNREGISTER);
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
//	  (*action_unregister)
	  e2_action_unregister (action_name);
	  g_free (action_name);
//  }
}

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/plugins/e2p_for_each.c <==
/* $Id: e2p_for_each.c 1388 2005-11-03 10:45:30Z tpgww $
 *
 * Copyright (C) 2003-2005 tooar <tooar@gmx.net>
 * Portions copyright (C) 1999 Michael Clark
 *
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include <string.h>
#include "e2_plugins.h"
#include "e2_dialog.h"
#include "e2_filelist.h"

static void for_each_dialog (void)
{
  gchar *s, *utf;
  GString *command;
  GList *base, *tmp;
  FileInfo *info;

  DialogButtons result = e2_dialog_line_input (_("repeat action"), 
		_("Enter an action to execute on each\n"
		"selected file:"),
		"", 0, FALSE, &s); 

  if (result == OK)
  { //a blank entry will not return OK
   	e2_filelist_disable_refresh ();
  	base = tmp = e2_fileview_get_selected_local (curr_view);
    if (base == NULL)
	{
		g_free (s);
	   	e2_filelist_enable_refresh ();
		return;
	}
	//FIXME support macros other than with english letters
    if (strstr (s, "%f") == NULL)
    {
      command = g_string_sized_new(128);
      for (; tmp != NULL; tmp = tmp->next)
      {
        info = tmp->data;
		utf = F_FILENAME_FROM_LOCALE (info->filename);
        g_string_printf (command, "%s \"%s\"", s, utf);
		e2_command_run (command->str, E2_COMMAND_RANGE_DEFAULT);
		F_FREE (utf);
      }
      g_string_free (command, TRUE);
    }
    else	//the command included "%f" already
    {
      for (; tmp != NULL; tmp = tmp->next)
      {
        info = tmp->data;
		utf = F_FILENAME_FROM_LOCALE (info->filename);
        if ((command = e2_utils_expand_macros (s, utf)) != NULL)
        {
          e2_command_run (command->str, E2_COMMAND_RANGE_DEFAULT);
          g_string_free (command, TRUE);
        }
		F_FREE (utf);
      }
    }
	g_free (s);
    g_list_free (base);
   	e2_filelist_enable_refresh ();
  }
}

//aname must be confined to this module
static gchar *aname;
/**
 * @brief plugin initialization function, called by main program
 *
 * @param p ptr to plugin data struct
 *
 * @return TRUE if the initialization succeeds, else FALSE
 **/
gboolean init_plugin (Plugin *p)
{
#define ANAME "foreach"
  aname = _("foreach");

  p->signature = ANAME VERSION;
  p->menu_name = _("For _each..");
  p->description = _("Execute an entered command on each selected item separately");
  p->icon = "plugin_"ANAME"_"E2IP".png";  //use icon file pathname if appropriate

  if (p->plugin_cb == NULL)
  {
	  p->plugin_cb = for_each_dialog;  //set plugins menu item function
//	  E2_Action* (*action_register) () = (*p->api_lookup) (E2API_ACTION_REGISTER);
	  //no need to free this
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
	  //NULL = no data, FALSE = no argument for the function
//	  (*action_register)
	  e2_action_register_simple (action_name, E2_ACTION_TYPE_ITEM, for_each_dialog, NULL, FALSE);
	  return TRUE;
  }
  return FALSE;
}
/**
 * @brief unload this plugin
 *
 * @param p pointer to data struct for the plugin
 *
 * @return
 **/
void unload_plugin (Plugin *p)
{
//  if (p->api_lookup != NULL)
//  {
//	  gboolean (*action_unregister) () = (*p->api_lookup) (E2API_ACTION_UNREGISTER);
	  gchar *action_name = g_strconcat (PLUGIN,".",aname,NULL);
//	  (*action_unregister)
	  e2_action_unregister (action_name);
	  g_free (action_name);
//  }
}
